Package: GSEAmining
Type: Package
Title: Make Biological Sense of Gene Set Enrichment Analysis Outputs
Version: 1.20.0
Authors@R: person("Oriol", "Arqués", email = "oriol.arques@gmail.com",
                  role = c("aut", "cre")) 
Description: Gene Set Enrichment Analysis is a very powerful and interesting 
  computational method that allows an easy correlation between differential 
  expressed genes and biological processes. Unfortunately, although it was 
  designed to help researchers to interpret gene
  expression data it can generate huge amounts of results whose biological 
  meaning can be difficult to interpret. 
  Many available tools rely on the hierarchically structured Gene Ontology (GO) 
  classification to reduce reundandcy in the results. However, due to the 
  popularity of GSEA many more gene set collections, such as those in the 
  Molecular Signatures Database are emerging. Since these collections 
  are not organized as those in GO, their usage for GSEA do not always give a 
  straightforward answer or, in other words, getting all the meaninful 
  information can be challenging with the currently available tools. For these 
  reasons, GSEAmining was born to be an easy tool to create reproducible reports 
  to help researchers make biological sense of GSEA outputs.
  Given the results of GSEA, GSEAmining clusters the different gene sets 
  collections based on the presence of the same genes in the leadind edge 
  (core) subset. Leading edge subsets are those genes that contribute most to
  the enrichment score of each collection of genes or gene sets. For this 
  reason, gene sets that participate in similar biological processes should 
  share genes in common and in turn cluster together. After that, GSEAmining is 
  able to identify and represent for each cluster: 
  - The most enriched terms in the names of gene sets (as wordclouds)
  - The most enriched genes in the leading edge subsets (as bar plots).
  In each case, positive and negative enrichments are shown in different colors 
  so it is easy to distinguish biological processes or genes that may be of 
  interest in that particular study.
License: GPL-3 | file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
Imports: dplyr, tidytext, dendextend, tibble, ggplot2, ggwordcloud,
        stringr, gridExtra, rlang, grDevices, graphics, stats, methods
Depends: R (>= 4.0)
Suggests: knitr, rmarkdown, BiocStyle, clusterProfiler, testthat, tm
VignetteBuilder: knitr
biocViews: GeneSetEnrichment, Clustering, Visualization
git_url: https://git.bioconductor.org/packages/GSEAmining
git_branch: RELEASE_3_22
git_last_commit: b5d7a90
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:21:29 UTC; biocbuild
Author: Oriol Arqués [aut, cre]
Maintainer: Oriol Arqués <oriol.arques@gmail.com>
